/*
 * Copyright 2014 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.exception;

/**
 * Base class for all unchecked exceptions thrown by this library. This library
 * uses unchecked exceptions for problems that are deemed non-recoverable (for
 * example if a malformed message is encountered). This does not mean that code
 * should not catch these exceptions. It might still make sense to catch them,
 * for example to log them or to send an error message to the peer. However,
 * these exceptions will not appear as part of the normal control flow (for
 * example a situation where a message cannot be sent due to a congestion and
 * should be queued for a later attempt).
 * 
 * @author Sebastian Marsching
 */
public class JackieRuntimeException extends RuntimeException {

    private static final long serialVersionUID = -7809055459356181759L;

    /**
     * Constructs a new exception with <code>null</code> as its detail message.
     * The cause is not initialized, and may subsequently be initialized by a
     * call to {@link #initCause}.
     */
    public JackieRuntimeException() {
        super();
    }

    /**
     * Constructs a new exception with the specified detail message. The cause
     * is not initialized, and may subsequently be initialized by a call to
     * {@link #initCause}.
     * 
     * @param message
     *            the detail message. The detail message is saved for later
     *            retrieval by the {@link #getMessage()} method.
     */
    public JackieRuntimeException(String message) {
        super(message);
    }

    /**
     * Constructs a new exception with the specified cause and a detail message
     * of <code>(cause==null ? null : cause.toString())</code> (which typically
     * contains the class and detail message of <code>cause</code>). This
     * constructor is useful for exceptions that are little more than wrappers
     * for other throwables.
     * 
     * @param cause
     *            the cause (which is saved for later retrieval by the
     *            {@link #getCause()} method). (A <code>null</code> value is
     *            permitted, and indicates that the cause is nonexistent or
     *            unknown.)
     */
    public JackieRuntimeException(Throwable cause) {
        super(cause);
    }

    /**
     * Constructs a new exception with the specified detail message and cause.
     * Note that the detail message associated with <code>cause</code> is not
     * automatically incorporated in this exception's detail message.
     * 
     * @param message
     *            the detail message (which is saved for later retrieval by the
     *            {@link #getMessage()} method).
     * @param cause
     *            the cause (which is saved for later retrieval by the
     *            {@link #getCause()} method). (A <code>null</code> value is
     *            permitted, and indicates that the cause is nonexistent or
     *            unknown.)
     */
    public JackieRuntimeException(String message, Throwable cause) {
        super(message, cause);
    }

}
